@@ -1,3 +1,13 @@
+from .accessControlAPI import (
+    AccessControlAPI,
+    get_groups,
+    get_group_by_name,
+    get_users,
+    get_users_by_groups,
+    get_users_count,
+
+)
+
 from .accessManagementAPI import (
     AccessManagementAPI,
     create_an_assignment,
@@ -126,10 +136,30 @@ from .kicsResultsAPI import (
     get_kics_results_by_scan_id,
 )
 from .KeycloakAPI import (
-    get_realms,
-    get_users,
-    create_a_new_user,
-    get_group_hierarchy,
+    AttackDetectionApi,
+    AuthenticationManagementApi,
+    ClientAttributeCertificateApi,
+    ClientInitialAccessApi,
+    ClientRegistrationPolicyApi,
+    ClientRoleMappingsApi,
+    ClientRolesApi,
+    ClientsApi,
+    ClientScopesApi,
+    ComponentApi,
+    GroupsApi,
+    IdentityProvidersApi,
+    KeyApi,
+    ProtocolMappersApi,
+    RealmsAdminApi,
+    RoleMapperApi,
+    RolesApi,
+    RolesByIdApi,
+    ScopeMappingsApi,
+    UsersApi,
+    # get_realms,
+    # get_users,
+    # create_a_new_user,
+    # get_group_hierarchy,
 )
 from .projectsAPI import (
     ProjectsAPI,
@@ -348,3 +378,9 @@ from .uploadsAPI import (
     create_a_pre_signed_url_to_upload_files,
     upload_zip_content_for_scanning,
 )
+from .versionsAPI import (
+    VersionsAPI
+)
+from .webhookAPI import (
+    WebHookAPI
+)
\ No newline at end of file
