@@ -11,6 +11,8 @@ class KicsResultCollection:
 
 def construct_kics_result_collection(item):
     return KicsResultCollection(
-        results=[construct_kics_result(result) for result in item.get("results") or []],
+        results=[
+            construct_kics_result(result) for result in item.get("results", [])
+        ],
         total_count=item.get("totalCount"),
     )
