@@ -4,7 +4,7 @@ from .CloudInsightContainer import CloudInsightContainer, construct_cloud_insigh
 
 
 @dataclass
-class PaginatedContainersListResponse(object):
+class PaginatedContainersListResponse:
     data: List[CloudInsightContainer] = None
     total: int = None
     current_page: int = None
@@ -13,7 +13,9 @@ class PaginatedContainersListResponse(object):
 
 def construct_paginated_containers_list_response(item):
     return PaginatedContainersListResponse(
-        data=[construct_cloud_insight_container(container) for container in item("data")],
+        data=[
+            construct_cloud_insight_container(container) for container in item("data", [])
+        ],
         total=item.get("total"),
         current_page=item.get("currentPage"),
         last_page=item.get("lastPage"),
