@@ -4,7 +4,7 @@ from .Resource import Resource, construct_resource
 
 
 @dataclass
-class PaginatedResourcesList(object):
+class PaginatedResourcesList:
     data: List[Resource] = None
     total: int = None
     current_page: int = None
@@ -13,7 +13,9 @@ class PaginatedResourcesList(object):
 
 def construct_paginated_resources_list(item):
     return PaginatedResourcesList(
-        data=[construct_resource(resource) for resource in item.get("data")],
+        data=[
+            construct_resource(resource) for resource in item.get("data", [])
+        ],
         total=item.get("total"),
         current_page=item.get("currentPage"),
         last_page=item.get("lastPage"),
