@@ -2,7 +2,7 @@ from dataclasses import dataclass
 
 
 @dataclass
-class TriageRequest(object):
+class TriageRequest:
     result_id: str = None
     project_id: str = None
     state: str = None
