@@ -20,7 +20,7 @@ def construct_configuration() -> Configuration:
     config = get_config(config_default=config_default, section="CxReporting", prefix="cxreporting_")
     return Configuration(
         server_base_url=config.get("reporting_client_url"),
-        token_url=f"{config.get("base_url")}/cxrestapi/auth/identity/connect/token",
+        token_url=f"{config.get('base_url')}/cxrestapi/auth/identity/connect/token",
         username=config.get("username"),
         password=config.get("password"),
         grant_type=config.get("grant_type"),
